## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 1;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

Name:           cfn-lint
Summary:        CloudFormation Linter
Version:        0.79.6
Release:        %autorelease

# SPDX
License:        MIT-0
URL:            https://github.com/aws-cloudformation/cfn-lint
# While the PyPI sdist contains the tests since 0.76.0, we still need data and
# documentation files that are only available in the GitHub archive.
Source0:        %{url}/archive/v%{version}/cfn-lint-%{version}.tar.gz
# Man page written for Fedora in groff_man(7) format based on --help output
Source1:        cfn-lint.1

# Revert "Pin jsonschema to be under 4.18 (#2792)"
#
# This reverts commit fc1ffe96c71a847d2ff1b01a18328648097c7e34.
#
# Upstream says, “The new version of json schema package has changed a lot of
# dependencies. This is a short term fix until we can better understand the
# full impact.” See https://github.com/aws-cloudformation/cfn-lint/pull/2792.
#
# This is a downstream-only patch; upstream really does want to pin the
# dependency, and we cannot respect the version pin and must make do with
# whatever is packaged.
Patch:          0001-Revert-Pin-jsonschema-to-be-under-4.18-2792.patch

BuildArch:      noarch

# https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}

BuildRequires:  python3-devel

# Graph generation requires either pygraphviz or pydot; tests expect the
# latter, but the former is preferred when both are installed.
BuildRequires:  python3dist(pydot)
Requires:       (python3dist(pygraphviz) or python3dist(pydot))

BuildRequires:  hardlink

BuildRequires:  python3dist(pytest)

# One function in cfnlint.maintenance calls “git grep”. It’s not entirely clear
# if this is really usable in a system-wide installation or not; it might be
# trying to operate on a git checkout of cfn-lint, which won’t be available. It
# doesn’t work for that reason when tested in
# TestUpdateDocumentation.test_update_docs, which is why there is no
# corresponding BuildRequires.
Recommends:     git-core

%py_provides python3-cfn-lint

%description
Validate AWS CloudFormation yaml/json templates against the AWS CloudFormation
Resource Specification and additional checks. Includes checking valid values
for resource properties and best practices.


%prep
%autosetup -p1


%generate_buildrequires
%pyproject_buildrequires


%build
%pyproject_wheel


%install
%pyproject_install
# This saves, as of this writing, roughly 250kB in duplicate data files and
# __init__.py files. Note that we do not pass “-t” because we do not want to
# ignore or discard differences in mtime. Note also that rpmlint will complain
# about cross-directory hardlinks, but that these are not a problem because the
# contents of a directory owned by this package are guaranteed to be on a
# single filesystem.
hardlink '%{buildroot}%{python3_sitelib}/cfnlint'
%pyproject_save_files cfnlint
install -t '%{buildroot}%{_mandir}/man1' -D -p -m 0644 '%{SOURCE1}'


%check
# These tests want to make HTTP(S) requests to the Internet:
k="${k-}${k+ and }not (TestFormatters and test_sarif_formatter)"
k="${k-}${k+ and }not (TestUpdateResourceSpecs and test_update_resource_specs_python_2)"
k="${k-}${k+ and }not (TestUpdateResourceSpecs and test_update_resource_specs_python_3)"

# This test tries to use “git grep”, but there is no git repository.
k="${k-}${k+ and }not (TestUpdateDocumentation and test_update_docs)"

# Tests fail if we parallelize with pytest-xdist… so don’t do that!
#
# LANG and AWS_DEFAULT_REGION are set as they are in tox.ini.
#
# We skip the TestCli tests the first time, then run them separately; they fail
# with the wrong region if run together with the other tests. This is probably
# a mocking issue. It doesn’t seem to be a problem when using unittest as the
# runner, as upstream does, but that would make it hard for us to skip tests
# (e.g. because they need network access).
k="${k-}${k+ and }not TestCli"
LANG=en_US.UTF-8 AWS_DEFAULT_REGION=us-east-1 %pytest -k "${k-}"
LANG=en_US.UTF-8 AWS_DEFAULT_REGION=us-east-1 %pytest -k 'TestCli'


%files -f %{pyproject_files}
# pyproject-rpm-macros handles LICENSE and NOTICE (verify with “rpm -qL -p …”)

# We don’t provide a separate documentation package since all of the following
# documentation is still not very big. As of this writing, it totals ~250kB
# extracted and a couple dozen files, in the context of a base package that is
# >100MB extracted with around a thousand files.
%doc CHANGELOG.md
%doc README.md
# Markdown
%doc docs/
%doc examples/

%{_bindir}/cfn-lint
%{_mandir}/man1/cfn-lint.1*


%changelog
* Sat Aug 12 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.79.6-1
- Update to 0.79.6

* Sat Jul 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.79.5-1
- Update to 0.79.5

* Sat Jul 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.78.1-1
- Update to 0.78.1

* Wed Jul 19 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.77.10-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_39_Mass_Rebuild

* Tue Jul 04 2023 Python Maint <python-maint@redhat.com> - 0.77.10-2
- Rebuilt for Python 3.12

* Tue Jun 20 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.77.10-1
- Update to 0.77.10

* Wed Apr 19 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.77.2-1
- Update to 0.77.2 (close RHBZ#2188056)

* Tue Apr 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.77.1-1
- Update to 0.77.1 (close RHBZ#2187434)

* Mon Apr 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.77.0-1
- Update to 0.77.0 (close RHBZ#2185615)

* Mon Apr 03 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.76.2-1
- Update to 0.76.2 (close RHBZ#2184199)

* Wed Mar 29 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.76.1-1
- Update to 0.76.1 (close RHBZ#2182154)
- Improve pygraphviz/pydot dependency and stop skipping the test

* Mon Mar 20 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.75.1-1
- Update to 0.75.1 (close RHBZ#2180137)

* Sun Mar 19 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.75.0-1
- Update to 0.75.0 (close RHBZ#2179144)

* Wed Mar 15 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.74.3-1
- Update to 0.74.3 (close RHBZ#2178217)

* Mon Mar 13 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.74.2-1
- Update to 0.74.2 (close RHBZ#2177880)

* Mon Mar 06 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.74.1-1
- Update to 0.74.1 (close RHBZ#2175858)

* Tue Feb 28 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.74.0-1
- Update to 0.74.0 (close RHBZ#2173746)

* Fri Feb 17 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.73.2-1
- Update to 0.73.2 (close RHBZ#2170935)

* Sat Feb 11 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.73.1-1
- Update to 0.73.1 (close RHBZ#2169011)

* Fri Feb 10 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.73.0-1
- Update to 0.73.0 (close RHBZ#2165108)

* Wed Jan 18 2023 Fedora Release Engineering <releng@fedoraproject.org> - 0.72.9-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_38_Mass_Rebuild

* Wed Jan 18 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.9-1
- Update to 0.72.9 (close RHBZ#2161737)

* Wed Jan 11 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.8-1
- Update to 0.72.8 (close RHBZ#2160267)

* Mon Jan 09 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.7-1
- Update to 0.72.7 (close RHBZ#2159513)

* Wed Jan 04 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.6-1
- Update to 0.72.6 (close RHBZ#2158030)

* Mon Dec 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.5-2
- Leaf package: remove i686 support

* Fri Dec 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.5-1
- Update to 0.72.5 (close RHBZ#2154353)

* Thu Dec 15 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.4-1
- Update to 0.72.4 (close RHBZ#2154101)

* Wed Dec 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.3-1
- Update to 0.72.3 (close RHBZ#2153591)

* Tue Dec 06 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.2-1
- Update to 0.72.2 (close RHBZ#2151048)

* Sun Nov 27 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.1-1
- Update to 0.72.1 (close RHBZ#2148742)

* Fri Nov 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.72.0-1
- Update to 0.72.0 (close RHBZ#2144968)

* Mon Nov 14 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.71.1-1
- Update to 0.71.1 (close RHBZ#2142656)

* Tue Nov 08 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.71.0-1
- Update to 0.71.0 (close RHBZ#2140725)

* Mon Oct 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.70.0-1
- Update to 0.70.0 (close RHBZ#2138931)

* Wed Oct 26 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.69.1-1
- Update to 0.69.1 (close RHBZ#2137688)

* Sat Oct 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.68.1-1
- Update to 0.68.1 (close RHBZ#2136904)

* Wed Oct 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.68.0-1
- Update to 0.68.0 (close RHBZ#2135951)
- Drop CODE_OF_CONDUCT.md and CONTRIBUTING.md from the package, as they are
  mostly relevant to upstream development

* Mon Oct 10 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.67.0-1
- Update to 0.67.0 (close RHBZ#2133469)

* Wed Oct 05 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.66.1-1
- Update to 0.66.1 (close RHBZ#2131077)

* Tue Sep 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.65.1-1
- Update to 0.65.1 (close RHBZ#2128106)

* Fri Sep 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.65.0-1
- Update to 0.65.0 (close RHBZ#2126573)

* Fri Sep 16 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.64.1-2
- Man page typo fixes

* Sun Sep 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.64.1-1
- Update to 0.64.1 (close RHBZ#2124643)

* Fri Sep 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.63.2-2
- Support for jsonschema 4.x is now via upstream PR#2336

* Wed Aug 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.63.2-1
- Update to 0.63.2 (close RHBZ#2122822)

* Tue Aug 30 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.63.1-1
- Update to 0.63.1 (close RHBZ#2122760)

* Thu Aug 25 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.63.0-1
- Update to 0.63.0 (close RHBZ#2119854)

* Thu Aug 11 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.5-1
- Update to 0.61.5 (close RHBZ#2117743)

* Sun Jul 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.4-2
- Confirm that License is SPDX MIT-0 (no License field change)

* Fri Jul 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.4-1
- Update to 0.61.4 (close RHBZ#2112420)

* Wed Jul 20 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.61.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_37_Mass_Rebuild

* Mon Jul 18 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.3-1
- Update to 0.61.3 (close RHBZ#2108237)

* Tue Jul 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.2-1
- Update to 0.61.2 (close RHBZ#2105446)

* Wed Jun 29 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.1-3
- Correctly allow jsonschema 4.x (close RHBZ#2101852)

* Tue Jun 28 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.1-2
- Allow jsonschema 4.x (close RHBZ#2101852)

* Thu Jun 23 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.1-1
- Update to 0.61.1 (close RHBZ#2100086)

* Wed Jun 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.0-2
- Rebuilt for Python 3.11 (close RHBZ#2098682)

* Wed Jun 01 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.61.0-1
- Update to 0.61.0 (close RHBZ#2092104)

* Fri May 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.60.1-1
- Update to 0.60.1 (close RHBZ#2088569)

* Fri May 13 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.60.0-1
- Update to 0.60.0 (close RHBZ#2085999)

* Mon May 02 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.59.1-1
- Update to 0.59.1 (close RHBZ#2081089)

* Wed Apr 20 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.59.0-2
- Install man page directly rather than copying to source tree first

* Wed Apr 13 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.59.0-1
- Update to 0.59.0 (close RHBZ#2074634)

* Tue Mar 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.4-1
- Update to 0.58.4 (close RHBZ#2066498)

* Tue Mar 08 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.3-1
- Update to 0.58.3 (close RHBZ#2061852)

* Sat Feb 26 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.2-1
- Update to 0.58.1 (close RHBZ#2058798)

* Tue Feb 22 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.1-1
- Update to 0.58.1 (close RHBZ#2056627)

* Mon Jan 31 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.58.0-1
- Update to 0.58.0 (close RHBZ#2048684)

* Wed Jan 19 2022 Fedora Release Engineering <releng@fedoraproject.org> - 0.57.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_36_Mass_Rebuild

* Wed Jan 19 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.57.0-1
- Update to 0.57.0 (close RHBZ#2042187)

* Wed Jan 12 2022 Benjamin A. Beasley <code@musicinmybrain.net> - 0.56.4-1
- Update to 0.56.3 (close RHBZ#2039002)

* Thu Dec 16 2021 Benjamin A. Beasley <code@musicinmybrain.net> - 0.56.3-1
- Initial package (close RHBZ#2033083)
